pub struct BalanceProofState {
pub nonce: Nonce,
pub transferred_amount: TokenAmount,
pub locked_amount: LockedAmount,
pub locksroot: Locksroot,
pub canonical_identifier: CanonicalIdentifier,
pub balance_hash: BalanceHash,
pub message_hash: Option<MessageHash>,
pub signature: Option<Signature>,
pub sender: Option<Address>,
}Expand description
Proof of a channel balance that can be used on-chain to resolve disputes.
Fields
nonce: Noncetransferred_amount: TokenAmountlocked_amount: LockedAmountlocksroot: Locksrootcanonical_identifier: CanonicalIdentifierbalance_hash: BalanceHashmessage_hash: Option<MessageHash>signature: Option<Signature>sender: Option<Address>Trait Implementations
Sourceimpl Clone for BalanceProofState
impl Clone for BalanceProofState
Sourcefn clone(&self) -> BalanceProofState
fn clone(&self) -> BalanceProofState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BalanceProofState
impl Debug for BalanceProofState
Sourceimpl<'de> Deserialize<'de> for BalanceProofState
impl<'de> Deserialize<'de> for BalanceProofState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BalanceProofState
Sourceimpl PartialEq for BalanceProofState
impl PartialEq for BalanceProofState
Sourcefn eq(&self, other: &BalanceProofState) -> bool
fn eq(&self, other: &BalanceProofState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BalanceProofState
impl Serialize for BalanceProofState
impl StructuralPartialEq for BalanceProofState