pub struct ContractSendChannelClose {
pub inner: ContractSendEventInner,
pub canonical_identifier: CanonicalIdentifier,
pub balance_proof: Option<BalanceProofState>,
}Expand description
Event emitted to close the netting channel. This event is used when a node needs to prepare the channel to unlock on-chain.
Fields
inner: ContractSendEventInnercanonical_identifier: CanonicalIdentifierbalance_proof: Option<BalanceProofState>Trait Implementations
Sourceimpl Clone for ContractSendChannelClose
impl Clone for ContractSendChannelClose
Sourcefn clone(&self) -> ContractSendChannelClose
fn clone(&self) -> ContractSendChannelClose
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContractSendChannelClose
impl Debug for ContractSendChannelClose
Sourceimpl Deref for ContractSendChannelClose
impl Deref for ContractSendChannelClose
Sourceimpl<'de> Deserialize<'de> for ContractSendChannelClose
impl<'de> Deserialize<'de> for ContractSendChannelClose
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractSendChannelClose
Sourceimpl Into<Event> for ContractSendChannelClose
impl Into<Event> for ContractSendChannelClose
Sourceimpl PartialEq for ContractSendChannelClose
impl PartialEq for ContractSendChannelClose
Sourcefn eq(&self, other: &ContractSendChannelClose) -> bool
fn eq(&self, other: &ContractSendChannelClose) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContractSendChannelClose
impl Serialize for ContractSendChannelClose
impl StructuralPartialEq for ContractSendChannelClose