pub struct PaymentReceivedSuccess {
pub token_network_registry_address: TokenNetworkRegistryAddress,
pub token_network_address: TokenNetworkAddress,
pub identifier: PaymentIdentifier,
pub amount: TokenAmount,
pub initiator: Address,
}Expand description
Event emitted when a payee has received a payment.
Note:
A payee knows if a lock claim has failed, but this is not sufficient
information to deduce when a transfer has failed, because the initiator may
try again at a different time and/or with different routes, for this reason
there is no correspoding EventTransferReceivedFailed.
Fields
token_network_registry_address: TokenNetworkRegistryAddresstoken_network_address: TokenNetworkAddressidentifier: PaymentIdentifieramount: TokenAmountinitiator: AddressTrait Implementations
Sourceimpl Clone for PaymentReceivedSuccess
impl Clone for PaymentReceivedSuccess
Sourcefn clone(&self) -> PaymentReceivedSuccess
fn clone(&self) -> PaymentReceivedSuccess
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentReceivedSuccess
impl Debug for PaymentReceivedSuccess
Sourceimpl<'de> Deserialize<'de> for PaymentReceivedSuccess
impl<'de> Deserialize<'de> for PaymentReceivedSuccess
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PaymentReceivedSuccess
Sourceimpl Into<Event> for PaymentReceivedSuccess
impl Into<Event> for PaymentReceivedSuccess
Sourceimpl PartialEq for PaymentReceivedSuccess
impl PartialEq for PaymentReceivedSuccess
Sourcefn eq(&self, other: &PaymentReceivedSuccess) -> bool
fn eq(&self, other: &PaymentReceivedSuccess) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PaymentReceivedSuccess
impl Serialize for PaymentReceivedSuccess
impl StructuralPartialEq for PaymentReceivedSuccess